@@ -1,14 +1,13 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 __all__ = [
     'main',
-    'DatClass',
-    'dataclass',
-    'is_dataclass',
-    'set_debug', 'set_extra',
     'DatGen',
+    'DatClass',
+    'set_debug',
+    'set_extra',
 ]
 
 import argparse
@@ -69,7 +68,8 @@ class DatClass:
                 setattr(self, attr_name, attr_type(**attr) if attr else None)
                 continue
             for item_type in get_args(attr_type):
-                setattr(self, attr_name, [item_type(**i) for i in getattr(self, attr_name)])
+                if is_dataclass(item_type):
+                    setattr(self, attr_name, [item_type(**i) for i in getattr(self, attr_name)])
 
 
 def main():
